# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import pulumi
from enum import Enum

__all__ = [
    'Algorithm',
    'CertificateType',
    'DatabaseSlug',
    'DropletSlug',
    'FileSystemType',
    'Protocol',
    'RecordType',
    'Region',
]


@pulumi.type_token("digitalocean:index:Algorithm")
class Algorithm(_builtins.str, Enum):
    ROUND_ROBIN = "round_robin"
    LEAST_CONNECTIONS = "least_connections"


@pulumi.type_token("digitalocean:index:CertificateType")
class CertificateType(_builtins.str, Enum):
    LETS_ENCRYPT = "lets_encrypt"
    CUSTOM = "custom"


@pulumi.type_token("digitalocean:index:DatabaseSlug")
class DatabaseSlug(_builtins.str, Enum):
    D_B_1_VPCU1_GB = "db-s-1vcpu-1gb"
    D_B_1_VPCU2_GB = "db-s-1vcpu-2gb"
    D_B_2_VPCU4_GB = "db-s-2vcpu-4gb"
    D_B_4_VPCU8_GB = "db-s-4vcpu-8gb"
    D_B_6_VPCU16_GB = "db-s-6vcpu-16gb"
    D_B_8_VPCU32_GB = "db-s-8vcpu-32gb"
    D_B_16_VPCU64_GB = "db-s-16vcpu-64gb"


@pulumi.type_token("digitalocean:index:DropletSlug")
class DropletSlug(_builtins.str, Enum):
    DROPLET_S1_VCPU512_MB10_GB = "s-1vcpu-512mb-10gb"
    DROPLET_S1_VCPU1_GB = "s-1vcpu-1gb"
    DROPLET_S1_VCPU1_G_B_AMD = "s-1vcpu-1gb-amd"
    DROPLET_S1_VCPU1_G_B_INTEL = "s-1vcpu-1gb-intel"
    DROPLET_S1_VCPU1_GB35_G_B_INTEL = "s-1vcpu-1gb-35gb-intel"
    DROPLET_S1_VCPU2_GB = "s-1vcpu-2gb"
    DROPLET_S1_VCPU2_G_B_AMD = "s-1vcpu-2gb-amd"
    DROPLET_S1_VCPU2_G_B_INTEL = "s-1vcpu-2gb-intel"
    DROPLET_S1_VCPU2_GB70_G_B_INTEL = "s-1vcpu-2gb-70gb-intel"
    DROPLET_S2_VCPU2_GB = "s-2vcpu-2gb"
    DROPLET_S2_VCPU2_G_B_AMD = "s-2vcpu-2gb-amd"
    DROPLET_S2_VCPU2_G_B_INTEL = "s-2vcpu-2gb-intel"
    DROPLET_S2_VCPU2_GB90_G_B_INTEL = "s-2vcpu-2gb-90gb-intel"
    DROPLET_S2_VCPU4_GB = "s-2vcpu-4gb"
    DROPLET_S2_VCPU4_G_B_AMD = "s-2vcpu-4gb-amd"
    DROPLET_S2_VCPU4_G_B_INTEL = "s-2vcpu-4gb-intel"
    DROPLET_S2_VCPU4_GB120_G_B_INTEL = "s-2vcpu-4gb-120gb-intel"
    DROPLET_S2_VCPU8_G_B_AMD = "s-2vcpu-8gb-amd"
    DROPLET_C2 = "c-2"
    DROPLET_C22_VCPU4_GB = "c2-2vcpu-4gb"
    DROPLET_S2_VCPU8_GB160_G_B_INTEL = "s-2vcpu-8gb-160gb-intel"
    DROPLET_S4_VCPU8_GB = "s-4vcpu-8gb"
    DROPLET_S4_VCPU8_G_B_AMD = "s-4vcpu-8gb-amd"
    DROPLET_S4_VCPU8_G_B_INTEL = "s-4vcpu-8gb-intel"
    DROPLET_G2_VCPU8_GB = "g-2vcpu-8gb"
    DROPLET_S4_VCPU8_GB240_G_B_INTEL = "s-4vcpu-8gb-240gb-intel"
    DROPLET_GD2_VCPU8_GB = "gd-2vcpu-8gb"
    DROPLET_G2_VCPU8_G_B_INTEL = "g-2vcpu-8gb-intel"
    DROPLET_GD2_VCPU8_G_B_INTEL = "gd-2vcpu-8gb-intel"
    DROPLET_S4_VCPU16_G_B_AMD = "s-4vcpu-16gb-amd"
    DROPLET_M2_VCPU16_GB = "m-2vcpu-16gb"
    DROPLET_C4 = "c-4"
    DROPLET_C24_VCPU8_GB = "c2-4vcpu-8gb"
    DROPLET_S4_VCPU16_GB320_G_B_INTEL = "s-4vcpu-16gb-320gb-intel"
    DROPLET_S8_VCPU16_GB = "s-8vcpu-16gb"
    DROPLET_M2_VCPU16_G_B_INTEL = "m-2vcpu-16gb-intel"
    DROPLET_M32_VCPU16_GB = "m3-2vcpu-16gb"
    DROPLET_C4_INTEL = "c-4-intel"
    DROPLET_M32_VCPU16_G_B_INTEL = "m3-2vcpu-16gb-intel"
    DROPLET_S8_VCPU16_G_B_AMD = "s-8vcpu-16gb-amd"
    DROPLET_S8_VCPU16_G_B_INTEL = "s-8vcpu-16gb-intel"
    DROPLET_C24_VCPU8_G_B_INTEL = "c2-4vcpu-8gb-intel"
    DROPLET_G4_VCPU16_GB = "g-4vcpu-16gb"
    DROPLET_S8_VCPU16_GB480_G_B_INTEL = "s-8vcpu-16gb-480gb-intel"
    DROPLET_SO2_VCPU16_G_B_INTEL = "so-2vcpu-16gb-intel"
    DROPLET_SO2_VCPU16_GB = "so-2vcpu-16gb"
    DROPLET_M62_VCPU16_GB = "m6-2vcpu-16gb"
    DROPLET_GD4_VCPU16_GB = "gd-4vcpu-16gb"
    DROPLET_SO1_52_VCPU16_G_B_INTEL = "so1_5-2vcpu-16gb-intel"
    DROPLET_G4_VCPU16_G_B_INTEL = "g-4vcpu-16gb-intel"
    DROPLET_GD4_VCPU16_G_B_INTEL = "gd-4vcpu-16gb-intel"
    DROPLET_SO1_52_VCPU16_GB = "so1_5-2vcpu-16gb"
    DROPLET_S8_VCPU32_G_B_AMD = "s-8vcpu-32gb-amd"
    DROPLET_M4_VCPU32_GB = "m-4vcpu-32gb"
    DROPLET_C8 = "c-8"
    DROPLET_C28_VCPU16_GB = "c2-8vcpu-16gb"
    DROPLET_S8_VCPU32_GB640_G_B_INTEL = "s-8vcpu-32gb-640gb-intel"
    DROPLET_M4_VCPU32_G_B_INTEL = "m-4vcpu-32gb-intel"
    DROPLET_M34_VCPU32_GB = "m3-4vcpu-32gb"
    DROPLET_C8_INTEL = "c-8-intel"
    DROPLET_M34_VCPU32_G_B_INTEL = "m3-4vcpu-32gb-intel"
    DROPLET_C28_VCPU16_G_B_INTEL = "c2-8vcpu-16gb-intel"
    DROPLET_G8_VCPU32_GB = "g-8vcpu-32gb"
    DROPLET_SO4_VCPU32_G_B_INTEL = "so-4vcpu-32gb-intel"
    DROPLET_SO4_VCPU32_GB = "so-4vcpu-32gb"
    DROPLET_M64_VCPU32_GB = "m6-4vcpu-32gb"
    DROPLET_GD8_VCPU32_GB = "gd-8vcpu-32gb"
    DROPLET_SO1_54_VCPU32_G_B_INTEL = "so1_5-4vcpu-32gb-intel"
    DROPLET_G8_VCPU32_G_B_INTEL = "g-8vcpu-32gb-intel"
    DROPLET_GD8_VCPU32_G_B_INTEL = "gd-8vcpu-32gb-intel"
    DROPLET_SO1_54_VCPU32_GB = "so1_5-4vcpu-32gb"
    DROPLET_M8_VCPU64_GB = "m-8vcpu-64gb"
    DROPLET_C16 = "c-16"
    DROPLET_C216_VCPU32_GB = "c2-16vcpu-32gb"
    DROPLET_M8_VCPU64_G_B_INTEL = "m-8vcpu-64gb-intel"
    DROPLET_M38_VCPU64_GB = "m3-8vcpu-64gb"
    DROPLET_C16_INTEL = "c-16-intel"
    DROPLET_M38_VCPU64_G_B_INTEL = "m3-8vcpu-64gb-intel"
    DROPLET_C216_VCPU32_G_B_INTEL = "c2-16vcpu-32gb-intel"
    DROPLET_G16_VCPU64_GB = "g-16vcpu-64gb"
    DROPLET_SO8_VCPU64_G_B_INTEL = "so-8vcpu-64gb-intel"
    DROPLET_SO8_VCPU64_GB = "so-8vcpu-64gb"
    DROPLET_M68_VCPU64_GB = "m6-8vcpu-64gb"
    DROPLET_GD16_VCPU64_GB = "gd-16vcpu-64gb"
    DROPLET_SO1_58_VCPU64_G_B_INTEL = "so1_5-8vcpu-64gb-intel"
    DROPLET_G16_VCPU64_G_B_INTEL = "g-16vcpu-64gb-intel"
    DROPLET_GD16_VCPU64_G_B_INTEL = "gd-16vcpu-64gb-intel"
    DROPLET_SO1_58_VCPU64_GB = "so1_5-8vcpu-64gb"
    DROPLET_M16_VCPU128_GB = "m-16vcpu-128gb"
    DROPLET_C32 = "c-32"
    DROPLET_C232_VCPU64_GB = "c2-32vcpu-64gb"
    DROPLET_M16_VCPU128_G_B_INTEL = "m-16vcpu-128gb-intel"
    DROPLET_M316_VCPU128_GB = "m3-16vcpu-128gb"
    DROPLET_C32_INTEL = "c-32-intel"
    DROPLET_M316_VCPU128_G_B_INTEL = "m3-16vcpu-128gb-intel"
    DROPLET_C232_VCPU64_G_B_INTEL = "c2-32vcpu-64gb-intel"
    DROPLET_C48 = "c-48"
    DROPLET_M24_VCPU192_GB = "m-24vcpu-192gb"
    DROPLET_G32_VCPU128_GB = "g-32vcpu-128gb"
    DROPLET_SO16_VCPU128_G_B_INTEL = "so-16vcpu-128gb-intel"
    DROPLET_SO16_VCPU128_GB = "so-16vcpu-128gb"
    DROPLET_M616_VCPU128_GB = "m6-16vcpu-128gb"
    DROPLET_GD32_VCPU128_GB = "gd-32vcpu-128gb"
    DROPLET_SO1_516_VCPU128_G_B_INTEL = "so1_5-16vcpu-128gb-intel"
    DROPLET_C248_VCPU96_GB = "c2-48vcpu-96gb"
    DROPLET_M24_VCPU192_G_B_INTEL = "m-24vcpu-192gb-intel"
    DROPLET_G32_VCPU128_G_B_INTEL = "g-32vcpu-128gb-intel"
    DROPLET_M324_VCPU192_GB = "m3-24vcpu-192gb"
    DROPLET_G40_VCPU160_GB = "g-40vcpu-160gb"
    DROPLET_GD32_VCPU128_G_B_INTEL = "gd-32vcpu-128gb-intel"
    DROPLET_SO1_516_VCPU128_GB = "so1_5-16vcpu-128gb"
    DROPLET_C48_INTEL = "c-48-intel"
    DROPLET_M324_VCPU192_G_B_INTEL = "m3-24vcpu-192gb-intel"
    DROPLET_M32_VCPU256_GB = "m-32vcpu-256gb"
    DROPLET_GD40_VCPU160_GB = "gd-40vcpu-160gb"
    DROPLET_C248_VCPU96_G_B_INTEL = "c2-48vcpu-96gb-intel"
    DROPLET_SO24_VCPU192_G_B_INTEL = "so-24vcpu-192gb-intel"
    DROPLET_SO24_VCPU192_GB = "so-24vcpu-192gb"
    DROPLET_M624_VCPU192_GB = "m6-24vcpu-192gb"
    DROPLET_M32_VCPU256_G_B_INTEL = "m-32vcpu-256gb-intel"
    DROPLET_C60_INTEL = "c-60-intel"
    DROPLET_M332_VCPU256_GB = "m3-32vcpu-256gb"
    DROPLET_SO1_524_VCPU192_G_B_INTEL = "so1_5-24vcpu-192gb-intel"
    DROPLET_M332_VCPU256_G_B_INTEL = "m3-32vcpu-256gb-intel"
    DROPLET_G48_VCPU192_G_B_INTEL = "g-48vcpu-192gb-intel"
    DROPLET_C260_VCPU120_G_B_INTEL = "c2-60vcpu-120gb-intel"
    DROPLET_GD48_VCPU192_G_B_INTEL = "gd-48vcpu-192gb-intel"
    DROPLET_SO1_524_VCPU192_GB = "so1_5-24vcpu-192gb"
    DROPLET_SO32_VCPU256_G_B_INTEL = "so-32vcpu-256gb-intel"
    DROPLET_SO32_VCPU256_GB = "so-32vcpu-256gb"
    DROPLET_M632_VCPU256_GB = "m6-32vcpu-256gb"
    DROPLET_SO1_532_VCPU256_G_B_INTEL = "so1_5-32vcpu-256gb-intel"
    DROPLET_G60_VCPU240_G_B_INTEL = "g-60vcpu-240gb-intel"
    DROPLET_M48_VCPU384_G_B_INTEL = "m-48vcpu-384gb-intel"
    DROPLET_GD60_VCPU240_G_B_INTEL = "gd-60vcpu-240gb-intel"
    DROPLET_GPUH100_X180_GB = "gpu-h100x1-80gb"
    DROPLET_SO1_532_VCPU256_GB = "so1_5-32vcpu-256gb"
    DROPLET_M348_VCPU384_G_B_INTEL = "m3-48vcpu-384gb-intel"
    DROPLET_SO48_VCPU384_G_B_INTEL = "so-48vcpu-384gb-intel"
    DROPLET_GPUH100_X180_GB200 = "gpu-h100x1-80gb-200"
    DROPLET_GPUH100_X8640_GB = "gpu-h100x8-640gb"
    DROPLET_GPUH100_X8640_GB200 = "gpu-h100x8-640gb-200"
    DROPLET16_GB = "16gb"
    DROPLET1_GB = "1gb"
    DROPLET2_GB = "2gb"
    DROPLET32_GB = "32gb"
    DROPLET48_GB = "48gb"
    DROPLET4_GB = "4gb"
    DROPLET512MB = "512mb"
    DROPLET64_GB = "64gb"
    DROPLET8_GB = "8gb"
    DROPLET_C22_VCPU8_GB = "c2-4vcpu-8gb"
    DROPLET_S12_VCPU48_GB = "s-12vcpu-48gb"
    DROPLET_S16_VCPU64_GB = "s-16vcpu-64gb"
    DROPLET_S1_VCPU3_GB = "s-1vcpu-3gb"
    DROPLET_S20_VCPU96_GB = "s-20vcpu-96gb"
    DROPLET_S24_VCPU128_GB = "s-24vcpu-128gb"
    DROPLET_S32_VCPU192_GB = "s-32vcpu-192gb"
    DROPLET_S3_VCPU1_GB = "s-3vcpu-1gb"
    DROPLET_S6_VCPU16_GB = "s-6vcpu-16gb"
    DROPLET_S8_VCPU32_GB = "s-8vcpu-32gb"
    DROPLET_SO1516_VCPU128_GB = "so1_5-16vcpu-128gb"
    DROPLET_SO1524_VCPU192_GB = "so1_5-24vcpu-192gb"
    DROPLET_SO152_VCPU16_GB = "so1_5-2vcpu-16gb"
    DROPLET_SO1532_VCPU256_GB = "so1_5-32vcpu-256gb"
    DROPLET_SO154_VCPU32_GB = "so1_5-4vcpu-32gb"
    DROPLET_SO158_VCPU64_GB = "so1_5-8vcpu-64gb"


@pulumi.type_token("digitalocean:index:FileSystemType")
class FileSystemType(_builtins.str, Enum):
    EXT4 = "ext4"
    XFS = "xfs"


@pulumi.type_token("digitalocean:index:Protocol")
class Protocol(_builtins.str, Enum):
    TCP = "tcp"
    UDP = "udp"
    ICMP = "icmp"
    HTTP = "http"
    HTTPS = "https"


@pulumi.type_token("digitalocean:index:RecordType")
class RecordType(_builtins.str, Enum):
    A = "A"
    AAAA = "AAAA"
    CAA = "CAA"
    CNAME = "CNAME"
    MX = "MX"
    NS = "NS"
    TXT = "TXT"
    SRV = "SRV"


@pulumi.type_token("digitalocean:index:Region")
class Region(_builtins.str, Enum):
    NYC1 = "nyc1"
    NYC2 = "nyc2"
    NYC3 = "nyc3"
    SGP1 = "sgp1"
    LON1 = "lon1"
    AMS2 = "ams2"
    AMS3 = "ams3"
    FRA1 = "fra1"
    TOR1 = "tor1"
    SFO1 = "sfo1"
    SFO2 = "sfo2"
    SFO3 = "sfo3"
    BLR1 = "blr1"
    SYD1 = "syd1"
